==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/apps/documents/l10n/fr.php <==
<?php $TRANSLATIONS = array(
"Format filter server is down or misconfigured" => "Le serveur de filtre de format est en panne ou mal configuré",
"Can't create document" => "Impossible de créer le document",
"You don't have permission to rename this document" => "Vous n'avez pas les droits suffisants pour renommer ce document",
"An error occurred while changing directory." => "Une erreur est survenue lors du changement de dossier.",
"Directory saved successfully." => "Dossier sauvegardé avec succès.",
"Documents" => "Documents",
"Failed to load documents." => "Échec du chargement des documents.",
"No documents are found. Please upload or create a document!" => "Aucun document n'a été trouvé. Veuillez charger ou créer un document !",
"Share" => "Partager",
"Close" => "Fermer",
"No connection to server. Trying to reconnect." => "Aucune connexion au serveur. Tentative de reconnection en cours.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Maintenir cette page dans le mode Éditeur empêche la sauvegarde des données. Il est recommandé d'utiliser le bouton 'Fermer'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Le chargement du document a échoué. Veuillez vérifier s'il peut être ouvert avec un éditeur odt externe. Il se peut également que le document a été récemment supprimé ou retiré d'un partage.",
"Save" => "Sauvegarder",
"Loading documents..." => "Chargement des documents...",
"'.' is an invalid file name." => "'.' n'est pas un nom de fichier valide.",
"File name cannot be empty." => "Le nom de fichier ne peut être vide.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nom invalide, les caractères '\\', '/', '<', '>', ':', '\"', '|', '?' et '*' ne sont pas autorisés.",
"Align Left" => "Aligner à gauche",
"Alignment" => "Alignement",
"Align Right" => "Aligner à droite",
"Annotate" => "Annoter",
"Background" => "Arrière-plan",
"Bold" => "Gras",
"Bottom" => "Bas de page",
"Cancel" => "Annuler",
"Center" => "Centrer",
"Clone" => "Dupliquer",
"Clone this Style" => "Dupliquer ce style",
"Color" => "Couleur",
"Create" => "Créer",
"Decrease Indent" => "Réduire l'indentation",
"Default Style" => "Style par défaut",
"Delete" => "Supprimer",
"Family" => "Famille",
"Font" => "Police",
"Font Effects" => "Effets de police",
"Format" => "Format",
"Increase Indent" => "Augmenter l'indentation",
"Insert Image" => "Insérer une image",
"Invite Members" => "Inviter des membres",
"Italic" => "Italique",
"Justified" => "Justifié",
"Justify" => "Justifier",
"Left" => "Gauche",
"Loading" => "Chargement",
"Members" => "Membres",
"New Name:" => "Nouveau nom :",
"OK" => "OK",
"Open" => "Ouvrir",
"Options" => "Options",
"Paragraph..." => "Paragraphe...",
"Paragraph Styles" => "Styles de paragraphe",
"Redo" => "Répéter",
"Right" => "Droite",
"Size" => "Taille",
"Spacing" => "Espacement",
"Strikethrough" => "Barré",
"Style" => "Style",
"Text" => "Texte",
"Top" => "Haut de page",
"Underline" => "Souligné",
"Undo" => "Annuler",
"Unknown Author" => "Auteur inconnu",
"Edit" => "Modifier",
"guest" => "Invité",
"MS Word support (requires openOffice/libreOffice)" => "Support de MS Word (nécessite openOffice/libreOffice)",
"Local" => "Local",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice est installé sur ce serveur. Le chemin au binaire est founi via preview_libreoffice_path dans config.php",
"External" => "Externe",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice est installé sur un serveur externe faisant fonctionner un serveur de filtre de format",
"scheme://domain.tld[:port]" => "scheme://domaine.tld[:port]",
"Server URL" => "URL du serveur",
"Apply" => "Appliquer",
"New document" => "Nouveau document",
"Upload (max. %s)" => "Envoi (max. %s)",
"Upload" => "Envoyer",
"Save new documents to" => "Enregistrer les nouveaux documents sous",
"Wrong password. Please retry." => "Mot de passe erroné. Merci de réessayer.",
"Password" => "Mot de passe",
"Guest %s" => "Invité %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Ce lien a expiré ou n'a jamais existé. Pour plus de détails, veuillez contacter la personne qui a créé ce partage avec vous.",
"Advanced feature-set" => "Fonctionnalités avancées",
"(Unstable)" => "(instable)"
);

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/apps/documents/l10n/fr.php <==
<?php $TRANSLATIONS = array(
"Format filter server is down or misconfigured" => "Le serveur de filtre de format est en panne ou mal configuré",
"Can't create document" => "Impossible de créer le document",
"You don't have permission to rename this document" => "Vous n'avez pas les droits suffisants pour renommer ce document",
"An error occurred while changing directory." => "Une erreur est survenue lors du changement de dossier.",
"Directory saved successfully." => "Dossier sauvegardé avec succès.",
"Documents" => "Documents",
"Failed to load documents." => "Échec du chargement des documents.",
"No documents are found. Please upload or create a document!" => "Aucun document n'a été trouvé. Veuillez charger ou créer un document !",
"Share" => "Partager",
"Close" => "Fermer",
"No connection to server. Trying to reconnect." => "Aucune connexion au serveur. Tentative de reconnection en cours.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Maintenir cette page dans le mode Éditeur empêche la sauvegarde des données. Il est recommandé d'utiliser le bouton 'Fermer'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Le chargement du document a échoué. Veuillez vérifier s'il peut être ouvert avec un éditeur odt externe. Il se peut également que le document a été récemment supprimé ou retiré d'un partage.",
"Save" => "Sauvegarder",
"Loading documents..." => "Chargement des documents...",
"'.' is an invalid file name." => "'.' n'est pas un nom de fichier valide.",
"File name cannot be empty." => "Le nom de fichier ne peut être vide.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nom invalide, les caractères '\\', '/', '<', '>', ':', '\"', '|', '?' et '*' ne sont pas autorisés.",
"Align Left" => "Aligner à gauche",
"Alignment" => "Alignement",
"Align Right" => "Aligner à droite",
"Annotate" => "Annoter",
"Background" => "Arrière-plan",
"Bold" => "Gras",
"Bottom" => "Bas de page",
"Cancel" => "Annuler",
"Center" => "Centrer",
"Clone" => "Dupliquer",
"Clone this Style" => "Dupliquer ce style",
"Color" => "Couleur",
"Create" => "Créer",
"Decrease Indent" => "Réduire l'indentation",
"Default Style" => "Style par défaut",
"Delete" => "Supprimer",
"Family" => "Famille",
"Font" => "Police",
"Font Effects" => "Effets de police",
"Format" => "Format",
"Increase Indent" => "Augmenter l'indentation",
"Insert Image" => "Insérer une image",
"Invite Members" => "Inviter des membres",
"Italic" => "Italique",
"Justified" => "Justifié",
"Justify" => "Justifier",
"Left" => "Gauche",
"Loading" => "Chargement",
"Members" => "Membres",
"New Name:" => "Nouveau nom :",
"OK" => "OK",
"Open" => "Ouvrir",
"Options" => "Options",
"Paragraph..." => "Paragraphe...",
"Paragraph Styles" => "Styles de paragraphe",
"Redo" => "Répéter",
"Right" => "Droite",
"Size" => "Taille",
"Spacing" => "Espacement",
"Strikethrough" => "Barré",
"Style" => "Style",
"Text" => "Texte",
"Top" => "Haut de page",
"Underline" => "Souligné",
"Undo" => "Annuler",
"Unknown Author" => "Auteur inconnu",
"Edit" => "Modifier",
"guest" => "Invité",
"MS Word support (requires openOffice/libreOffice)" => "Prise en charge de MS Word (nécessite openOffice/libreOffice)",
"Local" => "Local",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice est installé sur ce serveur. Le chemin au binaire est founi via preview_libreoffice_path dans config.php",
"External" => "Externe",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice est installé sur un serveur externe faisant fonctionner un serveur de filtre de format",
"scheme://domain.tld[:port]" => "scheme://domaine.tld[:port]",
"Server URL" => "URL du serveur",
"Apply" => "Appliquer",
"New document" => "Nouveau document",
"Upload (max. %s)" => "Envoi (max. %s)",
"Upload" => "Envoyer",
"Save new documents to" => "Enregistrer les nouveaux documents sous",
"Wrong password. Please retry." => "Mot de passe erroné. Merci de réessayer.",
"Password" => "Mot de passe",
"Guest %s" => "Invité %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Ce lien a expiré ou n'a jamais existé. Pour plus de détails, veuillez contacter la personne qui a créé ce partage avec vous.",
"Advanced feature-set" => "Fonctionnalités avancées",
"(Unstable)" => "(instable)"
);
